
public interface OurList<T> {
    /**
     * Returns the element at the specified position in the list.
     * @param index Index of the element to return.
     * @return The element at index.
     * @throws IndexOutOfBoundsException If the index is too large or negative.
     */
    public T get(int index) throws IndexOutOfBoundsException;

    /**
     * Sets the value at the specified position in the list.
     * @param index Index of the element to change.
     * @param value Value to put at the index.
     * @throws IndexOutOfBoundsException If the index is too large or negative.
     */
    public void set(int index, T value) throws IndexOutOfBoundsException;

    /**
     * Add a new element to the end of the list.
     * @param value The value of the element to add.
     */
    public void append(T value);

    /**
     * Adds an element at the specified position in the list, shifting later elements.
     * @param index Index to put the new element.
     * @param value Value of the new element.
     * @throws IndexOutOfBoundsException
     */
    public void insert(int index, T value) throws IndexOutOfBoundsException;

    /**
     * Removes the element at the specified position in the list.
     * @param index Index of the element to remove.
     * @return The value of the returned element.
     * @throws IndexOutOfBoundsException If the index is too large or negative.
     */
    public String delete(int index) throws IndexOutOfBoundsException;

    /**
     * Returns the number of elements in the list.
     * @return The number of elements in the list.
     */
    public int size();
}
